#!/bin/sh
#  _    _          ___           __ _     (R)
# | |  (_)_ _____ / __|___ _ _  / _(_)__ _
# | |__| \ V / -_) (__/ _ \ ' \|  _| / _` |
# |____|_|\_/\___|\___\___/_||_|_| |_\__, |
#                                    |___/
# Copyright (c) 2009-2014 Keppler IT GmbH.
# ----------------------------------------------------------------------------
# common/tools/cron.awstats.sh
# $Id$
# 
# Shell script to create/update AWStats statistics (via cron)
# ----------------------------------------------------------------------------

set -e

[ -d /etc/awstats/liveconfig ] || exit 0
. /etc/liveconfig/sysconfig || exit 0

AWSTATS=/usr/lib/cgi-bin/awstats.pl
if [ -x /var/www/awstats/awstats.pl ]; then AWSTATS=/var/www/awstats/awstats.pl; fi
if [ -x /srv/www/cgi-bin/awstats.pl ]; then AWSTATS=/srv/www/cgi-bin/awstats.pl; fi
if [ -x /usr/bin/awstats.pl ]; then AWSTATS=/usr/bin/awstats.pl; fi
if [ -x /usr/share/awstats/wwwroot/cgi-bin/awstats.pl ]; then AWSTATS=/usr/share/awstats/wwwroot/cgi-bin/awstats.pl; fi
STATICPAGES=/usr/share/awstats/tools/awstats_buildstaticpages.pl
if [ -x /usr/bin/awstats_buildstaticpages.pl ]; then STATICPAGES=/usr/bin/awstats_buildstaticpages.pl; fi
if [ -x /usr/share/doc/packages/awstats/examples/awstats_buildstaticpages.pl ]; then STATICPAGES=/usr/share/doc/packages/awstats/examples/awstats_buildstaticpages.pl; fi
AWSTATS_NICE=10
YEAR=`date +%Y`
MONTH=`date +%m`
DAY=`date +%d`
SORT=sort
SED=/bin/sed
FIND=find

# ----------------------------------------------------------------------------
# helper function to run "awstats_buildstaticpages.pl"
# ----------------------------------------------------------------------------
make_stats() {
  # $1: subscription name (eg. 'web1' or 'A12345')
  # $2: base name of webspace (eg. '/var/www/web1')
  # $3: year (eg. '2012')
  # $4: month (eg. '02')
  mkdir -p $2/stats/$3-$4/
  nice -n $AWSTATS_NICE $STATICPAGES -awstatsprog=$AWSTATS -config=$1 -configdir=/etc/awstats/liveconfig -staticlinks -year=$3 -month=$4 -dir=$2/stats/$3-$4/ >/dev/null
  # rename default page name (awstats.XXX.html) to index.html
  mv $2/stats/$3-$4/awstats.$1.html $2/stats/$3-$4/index.html
}

cd /etc/awstats/liveconfig

for c in `/bin/ls -1 awstats.*.conf 2>/dev/null \
          | sed 's/^awstats\.\(.*\)\.conf/\1/'`
do
  BASE=`grep '^LogFile' awstats.$c.conf | sed 's/LogFile="\(.*\)\/logs\/access.log"/\1/'`
  if [ ! -f "$BASE/logs/access.log.1" ] && [ ! -f "$BASE/logs/access.log" ]; then
    continue
  fi
  # first check rotated log file!
  if [ -f "$BASE/logs/access.log.1" ]; then
    nice -n $AWSTATS_NICE $AWSTATS -config=$c -configdir=/etc/awstats/liveconfig -LogFile=$BASE/logs/access.log.1 -update -debug=0 >/dev/null
  fi
  # now check normal log file
  if [ -f "$BASE/logs/access.log" ]; then
    nice -n $AWSTATS_NICE $AWSTATS -config=$c -configdir=/etc/awstats/liveconfig -LogFile=$BASE/logs/access.log -update -debug=0 >/dev/null
  fi
  if [ $DAY = "01" ]; then
    # this is the first day in a month
    # so also update stats from yesterday (previous month)
    YESTERDAY=$((`date +%s` - 86400))
    TMPYEAR=`date -d@$YESTERDAY +%Y`
    TMPMONTH=`date -d@$YESTERDAY +%m`
    make_stats $c $BASE $TMPYEAR $TMPMONTH
  fi
  make_stats $c $BASE $YEAR $MONTH

  # create HTML page containing navigation dropdown (awstats.nav.html)
  # this will be embedded into statistics pages using an <iframe> tag
  echo "<!DOCTYPE html>
<html><head><title>Navigation</title><link rel=\"stylesheet\" href=\"awstats/awstats.css\"></head>
<body id=\"bNav\"><form action=\"#\" method=\"get\"><select name=\"s\" id=\"sNav\" onchange=\"if (this.selectedIndex>0) top.location.href=this.options[this.selectedIndex].value + '/index.html'\">
<option>YYYY-MM</option>" > $BASE/stats/awstats-nav.html.tmp
  MONTHS=`$FIND $BASE/stats -maxdepth 1 -type d -name '????-??' | \
    $SED 's/^.*\(....-..\)$/\1/' | \
    $SORT -r`
  for m in $MONTHS
  do
    echo "<option value=\"$m\">$m</option>" >> $BASE/stats/awstats-nav.html.tmp
  done
  echo "</select></form></body></html>" >> $BASE/stats/awstats-nav.html.tmp
  mv $BASE/stats/awstats-nav.html.tmp $BASE/stats/awstats-nav.html

  # create "index.html" page in stats home directory, forwarding the user
  # to the most recent statistics page
  echo "<!DOCTYPE html>
<html><head><title>Statistics</title><meta http-equiv=\"Expires\" content=\"0\"/><meta http-equiv=\"Pragma\" content=\"no-cache\"/><meta http-equiv=\"refresh\" content=\"0;url=$YEAR-$MONTH/index.html\"/></head>
<body></body></html>" > $BASE/stats/index.html

done

# <EOF>-----------------------------------------------------------------------
