#!/bin/sh
#  _    _          ___           __ _     (R)
# | |  (_)_ _____ / __|___ _ _  / _(_)__ _
# | |__| \ V / -_) (__/ _ \ ' \|  _| / _` |
# |____|_|\_/\___|\___\___/_||_|_| |_\__, |
#                                    |___/
# Copyright (c) LiveConfig GmbH.
# ----------------------------------------------------------------------------
# common/tools/cron.php.sh
# $Id$
# 
# Shell script to remove expired PHP session files (via cron)
# php.ini setting "session.gc_maxlifetime" is retrieved by
# /usr/lib/liveconfig/php-session-maxlifetime - this switches to the actual
# user before executing PHP (for security reasons), so this cron job must
# be run as root.
# ----------------------------------------------------------------------------

set -e

. /etc/liveconfig/sysconfig || exit 0

# Default expire time: 1440 seconds = 24 minutes
EXPIRE=1440

# prevent multiple instances running at the same time
USER_ID=$(id -u)
for pid in $(pgrep -u $USER_ID -f "/bin/sh /usr/lib/liveconfig/cron.php.sh"); do
  if [ $pid != $$ ]; then
    echo "[$(date)] cron.php.sh is already running with PID $pid - aborting..." >&2
    exit 1
  fi  
done

if which php >/dev/null 2>&1 && [ -d "$LC_WEBROOT" ]; then
  # detect version of default PHP-CLI binary:
  PHPVERSION=`php -r 'echo phpversion();' | cut -d '.' -f 1`
  cd "$LC_WEBROOT"
  for cust in *; do
    [ -d "$cust" -a -d "$cust/tmp" ] || continue

    # check if user '$cust' exists
    CHECK_USER=$(id -u "$cust" > /dev/null 2>&1; echo $?)
    [ "$CHECK_USER" = "0" ] || continue

    # get session.gc_maxlifetime
    max=$EXPIRE
    if [ "x$PHPVERSION" = "x7" ] && [ -e "$cust/conf/php7/php.ini" ]; then
      cur=$(/usr/lib/liveconfig/php-session-lifetime -u $cust -i "$cust/conf/php7/php.ini")
    elif [ -e "$cust/.php5/php.ini" ]; then
      cur=$(/usr/lib/liveconfig/php-session-lifetime -u $cust -i "$cust/.php5/php.ini")
    elif [ -e "$cust/conf/php5/php.ini" ]; then
      cur=$(/usr/lib/liveconfig/php-session-lifetime -u $cust -i "$cust/conf/php5/php.ini")
    fi
    [ -z "$cur" ] && cur=0
    [ "$cur" -gt "$max" ] && max=$cur
    max=$(($max/60))
    find "$cust/tmp" -maxdepth 1 -type f -cmin +$max -regex ".*/sess_[a-z0-9]*" -delete
  done
fi

exit 0

# <EOF>-----------------------------------------------------------------------
